#include <Wire.h>

const int buttonPin = 9; // Pin connected to the push button
bool ledState1 = false;  // Initial LED state for slave 1
bool ledState2 = false;  // Initial LED state for slave 2

void setup() {
  pinMode(buttonPin, INPUT_PULLUP); // Set the button pin as an input with internal pull-up resistor
  Wire.begin();                     // Join I2C bus
  Serial.begin(9600);               // Start serial communication
  
  // Initial state: Turn off LED on slave 1 and turn on LED on slave 2
  Wire.beginTransmission(8); // Start communication with slave address 8 (first slave)
  Wire.write(0); // Turn off LED on slave 1
  Wire.endTransmission();    // End communication
  
  Wire.beginTransmission(9); // Start communication with slave address 9 (second slave)
  Wire.write(1); // Turn on LED on slave 2
  Wire.endTransmission();    // End communication
}

void loop() {
  int buttonState = digitalRead(buttonPin); // Read the state of the button
  
  // If the button is pressed, toggle the LEDs on the slave devices
  if (buttonState == LOW) {
    ledState1 = !ledState1; // Toggle LED state for slave 1
    ledState2 = !ledState2; // Toggle LED state for slave 2
    
    // Send command to toggle LED on slave 1
    Wire.beginTransmission(8); // Start communication with slave address 8 (first slave)
    Wire.write(ledState1 ? 1 : 0); // Send command to toggle LED based on the current LED state
    Wire.endTransmission();    // End communication

    // Send command to toggle LED on slave 2
    Wire.beginTransmission(9); // Start communication with slave address 9 (second slave)
    Wire.write(ledState2 ? 0 : 1); // Send command to toggle LED based on the current LED state
    Wire.endTransmission();    // End communication
    
    delay(500);                 // Delay to debounce the button
  }

  delay(100); // Small delay between readings for stability
}
