#include <Wire.h>

#define BUTTON_PIN 9          // Pin connected to the push button
#define SLAVE_ADDRESS_1 0x12  // Address of the first ATtiny412 slave device
#define SLAVE_ADDRESS_2 0x34  // Address of the second ATtiny412 slave device

uint8_t selectedSlave = SLAVE_ADDRESS_1;  // Initialize selected slave address

void setup() {
  pinMode(BUTTON_PIN, INPUT_PULLUP);  // Configure button pin as input with pull-up resistor
  Wire.begin();                       // Initialize I2C communication
}

void loop() {
  // Detect button press to change selected slave
  if (digitalRead(BUTTON_PIN) == LOW) {
    // Button is pressed, change selected slave
    if (selectedSlave == SLAVE_ADDRESS_1) {
      selectedSlave = SLAVE_ADDRESS_2;
      digitalWrite(1, HIGH);  // Turn on built-in LED to indicate selected slave 2
    } else {
      selectedSlave = SLAVE_ADDRESS_1;
      digitalWrite(1, LOW);  // Turn off built-in LED to indicate selected slave 1
    }
    delay(200);  // Debouncing delay
  }

  // Send selected slave address over I2C
  Wire.beginTransmission(selectedSlave);  // Begin transmission to selected slave
  Wire.write(selectedSlave);              // Send selected slave address
  Wire.endTransmission();                 // End transmission

  delay(100);  // Add a small delay if needed
}
